==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/da.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktiviteter",
    "An error occurred while loading activities" : "Der opstod en fejl under indlæsning af aktiviteter",
    "No activity yet" : "Ingen aktiviteter endnu",
    "Load more activities" : "Indlæs flere aktiviteter",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for kopi.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for kopi.",
    "Home" : "Hjem",
    "{name} (invisible)" : "{name} (usynlig)",
    "{name} (restricted)" : "{name} (begrænset)",
    "in {path}" : "i {path}",
    "This stream will show events like additions, changes & shares" : "Dette område vil vise begivenheder som tilføjelser, ændringer & delinger",
    "There are no events for this filter" : "Der ingen aktiviteter for dette filter",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Open file" : "Åben dokument",
    "Personal activity feed for %s" : "Personlige aktiviteter for %s ",
    "Your feed URL is invalid" : "Din feed-URL er ugyldg",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "Settings have been updated." : "Indstillingerne er blevet opdateret.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "All activities" : "Alle aktiviteter",
    "By others" : "Af andre",
    "By you" : "Af dig",
    "\"remote user\"" : "\"ekstern bruger\"",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "There was some activity at %s" : "Der var noget aktivitet omkring %s",
    "_and %n more _::_and %n more _" : ["og %n mere ","og %n flere"],
    "Activity notification" : "Notifikation om aktivitet",
    ", " : ", ",
    "%s and %s" : "%s og %s",
    "Activity" : "Aktivitet",
    "Activity feed" : "Feed med aktiviteter",
    "Send activity emails" : "Send aktivitets email",
    "Default settings" : "Standardindstillinger",
    "Configure the default activity settings for new users." : "Konfigurer standard aktivitetsindstillingerne for nye brugere.",
    "List your own actions in the stream" : "Vis dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Giv meddelelse om egne handlinger via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Du skal angive din e-mailadresse før du kan modtage notifikationer via e-mail.",
    "Send emails:" : "Send e-mails:",
    "As soon as possible" : "Så hurtigt som muligt",
    "Hourly" : "Hver time",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Vælg for hvilke aktiviteter du vil modtage en email notifikation og hvilke der skal vises i aktivitet app stream.",
    "Choose which activities you want to see in your stream." : "Vælg hvilke aktiviteter der skal vises i din stream.",
    "Settings" : "Indstillinger",
    "Enable RSS feed" : "Aktiverer RSS feed",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Der er Ikke flere aktiviteter som kan indlæses",
    "Files" : "Filer",
    "Error loading activities" : "Fejl ved indlæsning af aktiviteter",
    "No activities" : "Ingen aktiviteter",
    "You are receiving this email because the following things happened at %s" : "Du modtager denne email fordi følgende er sket på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n mere","* og %n mere"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/da.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktiviteter",
    "An error occurred while loading activities" : "Der opstod en fejl under indlæsning af aktiviteter",
    "No activity yet" : "Ingen aktiviteter endnu",
    "Load more activities" : "Indlæs flere aktiviteter",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for kopi.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for kopi.",
    "Home" : "Hjem",
    "{name} (invisible)" : "{name} (usynlig)",
    "{name} (restricted)" : "{name} (begrænset)",
    "in {path}" : "i {path}",
    "This stream will show events like additions, changes & shares" : "Dette område vil vise begivenheder som tilføjelser, ændringer & delinger",
    "There are no events for this filter" : "Der ingen aktiviteter for dette filter",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "Open file" : "Åben dokument",
    "Personal activity feed for %s" : "Personlige aktiviteter for %s ",
    "Your feed URL is invalid" : "Din feed-URL er ugyldg",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "Settings have been updated." : "Indstillingerne er blevet opdateret.",
    "All activities" : "Alle aktiviteter",
    "By others" : "Af andre",
    "By you" : "Af dig",
    "\"remote user\"" : "\"ekstern bruger\"",
    "Activity notification for %s" : "Aktivitet notifikation for %s",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "There was some activity at %s" : "Der var noget aktivitet omkring %s",
    "_and %n more _::_and %n more _" : ["og %n mere ","og %n flere"],
    ", " : ", ",
    "%s and %s" : "%s og %s",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "Activity" : "Aktivitet",
    "Activity feed" : "Feed med aktiviteter",
    "Send activity emails" : "Send aktivitets email",
    "Default settings" : "Standardindstillinger",
    "Configure the default activity settings for new users." : "Konfigurer standard aktivitetsindstillingerne for nye brugere.",
    "List your own actions in the stream" : "Vis dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Giv meddelelse om egne handlinger via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Du skal angive din e-mailadresse før du kan modtage notifikationer via e-mail.",
    "Send emails:" : "Send e-mails:",
    "As soon as possible" : "Så hurtigt som muligt",
    "Hourly" : "Hver time",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Vælg for hvilke aktiviteter du vil modtage en email notifikation og hvilke der skal vises i aktivitet app stream.",
    "Choose which activities you want to see in your stream." : "Vælg hvilke aktiviteter der skal vises i din stream.",
    "Settings" : "Indstillinger",
    "Enable RSS feed" : "Aktivér RSS feed",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Der er Ikke flere aktiviteter som kan indlæses",
    "Files" : "Filer",
    "Activity notification" : "Notifikation om aktivitet"
},
"nplurals=2; plural=(n != 1);");
